@@ -35,14 +35,14 @@
 #include <tqdict.h>
 
 //KDE includes
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kdirselectdialog.h>
 #include <keditlistbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kprogress.h>
 #include <kurl.h>
 
@@ -110,7 +110,7 @@ namespace BookshelfManager {
 		layout->addWidget(m_swordAddPathButton, 3,3);
 
 		m_swordRemovePathButton = new TQPushButton(i18n("Remove Entry"), page);
-		m_swordRemovePathButton->setIconSet(SmallIcon("editdelete", 16));
+		m_swordRemovePathButton->setIconSet(SmallIcon("edit-delete", 16));
 		connect(m_swordRemovePathButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slot_swordRemoveClicked()));
 		layout->addWidget(m_swordRemovePathButton, 4,3);
 
@@ -161,7 +161,7 @@ the module remote installation feature!</b>")
 		layout->addWidget(deleteSourceButton, 2, 1, TQt::AlignLeft);
 
 		TQPushButton* addSourceButton = new TQPushButton(i18n("Add library"), m_installSourcePage);
-		addSourceButton->setIconSet(SmallIcon("folder_new", 16));
+		addSourceButton->setIconSet(SmallIcon("folder-new", 16));
 		connect(addSourceButton, TQT_SIGNAL(clicked()), TQT_SLOT(slot_installAddSource()));
 		layout->addWidget(addSourceButton, 2, 2, TQt::AlignLeft);
 
@@ -449,7 +449,7 @@ the module remote installation feature!</b>")
 
 	void CSwordSetupDialog::populateRemoveModuleListView() {
 		CSwordBackend myBackend;
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 		myBackend.initModules();
 
 		m_removeModuleListView->clear();
@@ -487,7 +487,7 @@ the module remote installation feature!</b>")
 		m_progressDialog->setMinimumDuration(0); //show immediately
 		m_progressDialog->setAutoClose(false);
 		m_progressDialog->show();
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 
 		connect(
 			m_progressDialog, TQT_SIGNAL(cancelClicked()),
@@ -507,8 +507,8 @@ the module remote installation feature!</b>")
 					m_refreshedRemoteSources = true;
 					success = true;
 				}
-				else { //an error occurres, the KIO library should display an error message
-					qWarning("InstallMgr: refreshRemoteSources returned an error.");
+				else { //an error occurres, the TDEIO library should display an error message
+					tqWarning("InstallMgr: refreshRemoteSources returned an error.");
 					m_refreshedRemoteSources = false;
 					success = false;
 				}
@@ -527,7 +527,7 @@ the module remote installation feature!</b>")
 	}
 
 	bool CSwordSetupDialog::populateInstallModuleListView( const TQString& sourceName ) {
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 		Q_ASSERT(m_installModuleListView);
 		if (!m_installModuleListView) { // this may be an update after removing modules
 			return false;
@@ -540,17 +540,17 @@ the module remote installation feature!</b>")
 
 		if (BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is)
 				&& !refreshRemoteModuleCache(sourceName)) {
-			//   qWarning("finish");
+			//   tqWarning("finish");
 			m_installModuleListView->finish();
 			return false;
 		}
 
 		//kind of a hack to provide a pointer to mgr next line
-		//   qWarning("createing remote_backend");
+		//   tqWarning("createing remote_backend");
 		util::scoped_ptr<CSwordBackend> remote_backend( BTInstallMgr::Tool::backend(&is) );
-		//  qWarning("config path1 is %s", remote_backend->configPath);
-		//  qWarning("config path2 is %s", BTInstallMgr::Tool::backend(&is)->configPath ); //mem leak
-		//   qWarning("after creating remote_backend");
+		//  tqWarning("config path1 is %s", remote_backend->configPath);
+		//  tqWarning("config path2 is %s", BTInstallMgr::Tool::backend(&is)->configPath ); //mem leak
+		//   tqWarning("after creating remote_backend");
 		Q_ASSERT(remote_backend);
 		Q_ASSERT( BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is) );
 		if (!remote_backend) {
@@ -560,22 +560,22 @@ the module remote installation feature!</b>")
 
 		CSwordBackend* local_backend = CPointers::backend();
 		Q_ASSERT(local_backend);
-		//  qWarning("local backend has path %s", local_backend->);
-		KApplication::kApplication()->processEvents();
+		//  tqWarning("local backend has path %s", local_backend->);
+		TDEApplication::kApplication()->processEvents();
 		//local_backend.initModules();
 
-		//  qWarning("config path3 is %s", remote_backend->configPath);
+		//  tqWarning("config path3 is %s", remote_backend->configPath);
 		ListCSwordModuleInfo mods = remote_backend->moduleList();
 		Q_ASSERT(mods.count() > 0);
 
 		ListCSwordModuleInfo::iterator end_it = mods.end();
 		for (ListCSwordModuleInfo::iterator it(mods.begin()); it != end_it; ++it) {
-			//   qWarning("adding module %s (%s)", (*it)->name().latin1(), (*it)->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
+			//   tqWarning("adding module %s (%s)", (*it)->name().latin1(), (*it)->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
 			bool isUpdate = false;
 
 			CSwordModuleInfo* const installedModule = local_backend->findModuleByName((*it)->name());
 			if (installedModule) {
-				//    qWarning("module is already installed in %s", installedModule->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
+				//    tqWarning("module is already installed in %s", installedModule->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
 			}
 			//     Q_ASSERT(installedModule);
 
@@ -591,7 +591,7 @@ the module remote installation feature!</b>")
 
 				isUpdate = (newVersion > installedVersion);
 				if (!isUpdate) {
-					//     qWarning("    mod %s is not an update", (*it)->name().latin1());
+					//     tqWarning("    mod %s is not an update", (*it)->name().latin1());
 					continue;
 				}
 			}
@@ -684,7 +684,7 @@ the module remote installation feature!</b>")
 	}
 
 	void CSwordSetupDialog::slot_installModules() {
-		qWarning("CSwordSetupDialog::slot_installModules()");
+		tqWarning("CSwordSetupDialog::slot_installModules()");
 		//   m_installContinueButton->setEnabled(false);
 		//   m_installBackButton->setEnabled(false);
 
@@ -703,7 +703,7 @@ the module remote installation feature!</b>")
 			m_currentInstallMgr = &iMgr;
 			sword::InstallSource is = BTInstallMgr::Tool::RemoteConfig::source(&iMgr, currentInstallSource());
 
-			qWarning("installing from %s/%s", is.source.c_str(), is.directory.c_str());
+			tqWarning("installing from %s/%s", is.source.c_str(), is.directory.c_str());
 			TQString target = m_targetCombo->currentText();
 
 			//make sure target/mods.d and target/modules exist
@@ -727,7 +727,7 @@ the module remote installation feature!</b>")
 			m_progressDialog->setMinimumDuration(0); //show immediately
 			m_progressDialog->setAutoClose(false);
 			m_progressDialog->show();
-			KApplication::kApplication()->processEvents();
+			TDEApplication::kApplication()->processEvents();
 
 			connect(
 				m_progressDialog, TQT_SIGNAL(cancelClicked()),
@@ -740,7 +740,7 @@ the module remote installation feature!</b>")
 
 			for ( TQStringList::Iterator it = moduleList.begin(); (it != moduleList.end()) && !m_progressDialog->wasCancelled(); ++it, ++m_installedModuleCount ) {
 
-				qWarning("installing %s", (*it).latin1());
+				tqWarning("installing %s", (*it).latin1());
 				m_installingModule = *it;
 
 				//check whether it's an update. If yes, remove existing module first
@@ -767,9 +767,9 @@ the module remote installation feature!</b>")
 
 				if (!m_progressDialog->wasCancelled()
 						&& BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is)) {
-					//        qWarning("calling install");
+					//        tqWarning("calling install");
 					int status = iMgr.installModule(&lMgr, 0, (*it).latin1(), &is);
-					//         qWarning("status: %d", status);
+					//         tqWarning("status: %d", status);
 					Q_ASSERT(status != -1);
 				}
 				else if (!m_progressDialog->wasCancelled()) { //local source
@@ -797,7 +797,7 @@ the module remote installation feature!</b>")
 			m_progressDialog->progressBar()->setProgress(total+100*m_installedModuleCount);
 			m_progressDialog->setLabel( i18n("[%1]: %2% complete").arg(m_installingModule).arg(total) );
 		}
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 	}
 
 	void CSwordSetupDialog::slot_showInstallSourcePage() {
@@ -910,14 +910,16 @@ the module remote installation feature!</b>")
 		if (m_currentInstallMgr) {
 			m_currentInstallMgr->terminate();
 		}
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 	}
 
 	void CSwordSetupDialog::slot_moduleRefreshCompleted(const int /*total*/, const int current) {
 		if (m_progressDialog) {
 			m_progressDialog->progressBar()->setProgress(current);
 		}
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 	}
 
 } // NAMESPACE
+
+#include "cswordsetupdialog.moc"
