@@ -34,11 +34,11 @@
 #include <tqregexp.h>
 
 //KDE includes
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
 
 using namespace Printing;
 
@@ -77,7 +77,7 @@ void CMainIndex::ToolTip::maybeTip(const TQPoint& p) {
 	}
 }
 
-CMainIndex::CMainIndex(TQWidget *parent) : KListView(parent),
+CMainIndex::CMainIndex(TQWidget *parent) : TDEListView(parent),
 m_searchDialog(0), m_toolTip(0), m_itemsMovable(false), m_autoOpenFolder(0), m_autoOpenTimer(this) {
 	initView();
 	initConnections();
@@ -143,40 +143,40 @@ void CMainIndex::initView() {
 	setSelectionModeExt(Extended);
 
 	//setup the popup menu
-	m_popup = new KPopupMenu(viewport());
+	m_popup = new TDEPopupMenu(viewport());
 	m_popup->insertTitle(i18n("Bookshelf"));
 
-	m_actions.newFolder = new KAction(i18n("Create a new folder"), CResMgr::mainIndex::newFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(createNewFolder()), TQT_TQOBJECT(this));
-	m_actions.changeFolder = new KAction(i18n("Change this folder"),CResMgr::mainIndex::changeFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeFolder()), TQT_TQOBJECT(this));
+	m_actions.newFolder = new TDEAction(i18n("Create a new folder"), CResMgr::mainIndex::newFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(createNewFolder()), TQT_TQOBJECT(this));
+	m_actions.changeFolder = new TDEAction(i18n("Change this folder"),CResMgr::mainIndex::changeFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeFolder()), TQT_TQOBJECT(this));
 
-	m_actions.changeBookmark = new KAction(i18n("Change bookmark description"),CResMgr::mainIndex::changeBookmark::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeBookmark()), TQT_TQOBJECT(this));
-	m_actions.importBookmarks = new KAction(i18n("Import bookmarks"),CResMgr::mainIndex::importBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(importBookmarks()), TQT_TQOBJECT(this));
-	m_actions.exportBookmarks = new KAction(i18n("Export bookmarks"),CResMgr::mainIndex::exportBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(exportBookmarks()), TQT_TQOBJECT(this));
-	m_actions.printBookmarks = new KAction(i18n("Print bookmarks"),CResMgr::mainIndex::printBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(printBookmarks()), TQT_TQOBJECT(this));
+	m_actions.changeBookmark = new TDEAction(i18n("Change bookmark description"),CResMgr::mainIndex::changeBookmark::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeBookmark()), TQT_TQOBJECT(this));
+	m_actions.importBookmarks = new TDEAction(i18n("Import bookmarks"),CResMgr::mainIndex::importBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(importBookmarks()), TQT_TQOBJECT(this));
+	m_actions.exportBookmarks = new TDEAction(i18n("Export bookmarks"),CResMgr::mainIndex::exportBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(exportBookmarks()), TQT_TQOBJECT(this));
+	m_actions.printBookmarks = new TDEAction(i18n("Print bookmarks"),CResMgr::mainIndex::printBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(printBookmarks()), TQT_TQOBJECT(this));
 
-	m_actions.deleteEntries = new KAction(i18n("Remove selected item(s)"),CResMgr::mainIndex::deleteItems::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(deleteEntries()), TQT_TQOBJECT(this));
+	m_actions.deleteEntries = new TDEAction(i18n("Remove selected item(s)"),CResMgr::mainIndex::deleteItems::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(deleteEntries()), TQT_TQOBJECT(this));
 
-	m_actions.editModuleMenu = new KActionMenu(i18n("Edit this work"),CResMgr::mainIndex::editModuleMenu::icon, TQT_TQOBJECT(this));
+	m_actions.editModuleMenu = new TDEActionMenu(i18n("Edit this work"),CResMgr::mainIndex::editModuleMenu::icon, TQT_TQOBJECT(this));
 	m_actions.editModuleMenu->setDelayed(false);
-	m_actions.editModulePlain = new KAction(i18n("Plain text"),CResMgr::mainIndex::editModulePlain::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModulePlain()), TQT_TQOBJECT(this));
-	m_actions.editModuleHTML = new KAction(i18n("HTML"),CResMgr::mainIndex::editModuleHTML::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModuleHTML()), TQT_TQOBJECT(this));
+	m_actions.editModulePlain = new TDEAction(i18n("Plain text"),CResMgr::mainIndex::editModulePlain::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModulePlain()), TQT_TQOBJECT(this));
+	m_actions.editModuleHTML = new TDEAction(i18n("HTML"),CResMgr::mainIndex::editModuleHTML::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModuleHTML()), TQT_TQOBJECT(this));
 	
-	m_actions.searchInModules = new KAction(i18n("Search in selected work(s)"),CResMgr::mainIndex::search::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(searchInModules()), TQT_TQOBJECT(this));
-	m_actions.unlockModule = new KAction(i18n("Unlock this work"),CResMgr::mainIndex::unlockModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(unlockModule()), TQT_TQOBJECT(this));
-	m_actions.aboutModule = new KAction(i18n("About this work"),CResMgr::mainIndex::aboutModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(aboutModule()), TQT_TQOBJECT(this));
+	m_actions.searchInModules = new TDEAction(i18n("Search in selected work(s)"),CResMgr::mainIndex::search::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(searchInModules()), TQT_TQOBJECT(this));
+	m_actions.unlockModule = new TDEAction(i18n("Unlock this work"),CResMgr::mainIndex::unlockModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(unlockModule()), TQT_TQOBJECT(this));
+	m_actions.aboutModule = new TDEAction(i18n("About this work"),CResMgr::mainIndex::aboutModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(aboutModule()), TQT_TQOBJECT(this));
 
 
 	//fill the popup menu itself
 	m_actions.newFolder->plug(m_popup);
 	m_actions.changeFolder->plug(m_popup);
-	(new KActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
 	m_actions.changeBookmark->plug(m_popup);
 	m_actions.importBookmarks->plug(m_popup);
 	m_actions.exportBookmarks->plug(m_popup);
 	m_actions.printBookmarks->plug(m_popup);
-	(new KActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
 	m_actions.deleteEntries->plug(m_popup);
-	(new KActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
 	m_actions.editModuleMenu->plug(m_popup);
 	//sub item of edit module menu
 	m_actions.editModuleMenu->insert(m_actions.editModulePlain); 
@@ -194,8 +194,8 @@ void CMainIndex::initConnections() {
 			TQT_SLOT(slotExecuted(TQListViewItem*)));
 	connect(this, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)),
 			TQT_SLOT(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)));
-	connect(this, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
-			TQT_SLOT(contextMenu(KListView*, TQListViewItem*, const TQPoint&)));
+	connect(this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+			TQT_SLOT(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
 	connect(&m_autoOpenTimer, TQT_SIGNAL(timeout()),
 			this, TQT_SLOT(autoOpenTimeout()));
 }
@@ -228,7 +228,7 @@ void CMainIndex::slotExecuted( TQListViewItem* i ) {
 /** Reimplementation. Returns the drag object for the current selection. */
 TQDragObject* CMainIndex::dragObject() {
 	if (!m_itemsMovable) {
-		return false;
+		return 0;
 	}
 
 	CDragDropMgr::ItemList dndItems;
@@ -252,7 +252,7 @@ TQDragObject* CMainIndex::dragObject() {
 	return CDragDropMgr::dragObject( dndItems, viewport() );
 }
 
-/** Reimplementation from KListView. Returns true if the drag is acceptable for the listview. */
+/** Reimplementation from TDEListView. Returns true if the drag is acceptable for the listview. */
 bool CMainIndex::acceptDrag( TQDropEvent* event ) const {
 	const TQPoint pos = contentsToViewport(event->pos());
 
@@ -365,8 +365,8 @@ void CMainIndex::emitModulesChosen( ListCSwordModuleInfo modules, TQString key )
 	emit createReadDisplayWindow(modules, key);
 }
 
-/** Returns the correct KAction object for the given type of action. */
-KAction* const CMainIndex::action( const CItemBase::MenuAction type ) const {
+/** Returns the correct TDEAction object for the given type of action. */
+TDEAction* const CMainIndex::action( const CItemBase::MenuAction type ) const {
 	switch (type) {
 	case CItemBase::NewFolder:
 		return m_actions.newFolder;
@@ -399,7 +399,7 @@ KAction* const CMainIndex::action( const CItemBase::MenuAction type ) const {
 }
 
 /** Shows the context menu at the given position. */
-void CMainIndex::contextMenu(KListView* /*list*/, TQListViewItem* i, const TQPoint& p) {
+void CMainIndex::contextMenu(TDEListView* /*list*/, TQListViewItem* i, const TQPoint& p) {
 	//setup menu entries depending on current selection
 	TQPtrList<TQListViewItem> items = selectedItems();
 
@@ -413,7 +413,7 @@ void CMainIndex::contextMenu(KListView* /*list*/, TQListViewItem* i, const TQPoi
 		CItemBase::MenuAction actionType;
 		for (int index = CItemBase::ActionBegin; index <= CItemBase::ActionEnd; ++index) {
 			actionType = static_cast<CItemBase::MenuAction>(index);
-			if (KAction* a = action(actionType))
+			if (TDEAction* a = action(actionType))
 				a->setEnabled( item->enableAction(actionType) );
 		}
 	}
@@ -422,7 +422,7 @@ void CMainIndex::contextMenu(KListView* /*list*/, TQListViewItem* i, const TQPoi
 		CItemBase::MenuAction actionType;
 		for (int index = CItemBase::ActionBegin; index <= CItemBase::ActionEnd; ++index) {
 			actionType = static_cast<CItemBase::MenuAction>(index);
-			if (KAction* a = action(actionType))
+			if (TDEAction* a = action(actionType))
 				a->setEnabled(false);
 		}
 
@@ -435,7 +435,7 @@ void CMainIndex::contextMenu(KListView* /*list*/, TQListViewItem* i, const TQPoi
 				enableAction = enableAction && i->enableAction(actionType);
 			}
 			if (enableAction) {
-				KAction* a = action(actionType) ;
+				TDEAction* a = action(actionType) ;
 				if (i && a)
 					a->setEnabled(enableAction);
 			}
@@ -603,12 +603,12 @@ void CMainIndex::startDrag() {
 		}
 	}
 
-	KListView::startDrag();
+	TDEListView::startDrag();
 }
 
 /** Reimplementation to support the items dragEnter and dragLeave functions. */
 void CMainIndex::contentsDragMoveEvent( TQDragMoveEvent* event ) {
-	//  qWarning("void CMainIndex:: drag move event ( TQDragLeaveEvent* e )");
+	//  tqWarning("void CMainIndex:: drag move event ( TQDragLeaveEvent* e )");
 	CItemBase* i = dynamic_cast<CItemBase*>( itemAt( contentsToViewport(event->pos())) );
 	if (i) {
 		if (i->allowAutoOpen(event) || (i->acceptDrop(event) && i->isFolder() && i->allowAutoOpen(event) && !i->isOpen() && autoOpen()) ) {
@@ -627,7 +627,7 @@ void CMainIndex::contentsDragMoveEvent( TQDragMoveEvent* event ) {
 		m_autoOpenFolder = 0;
 	}
 
-	KListView::contentsDragMoveEvent(event);
+	TDEListView::contentsDragMoveEvent(event);
 }
 
 TQRect CMainIndex::drawItemHighlighter(TQPainter* painter, TQListViewItem* item) {
@@ -637,7 +637,7 @@ TQRect CMainIndex::drawItemHighlighter(TQPainter* painter, TQListViewItem* item)
 		return TQRect();
 	}
 
-	return KListView::drawItemHighlighter(painter, item);
+	return TDEListView::drawItemHighlighter(painter, item);
 }
 
 
@@ -651,7 +651,7 @@ void CMainIndex::autoOpenTimeout() {
 /** No descriptions */
 void CMainIndex::contentsDragLeaveEvent( TQDragLeaveEvent* e ) {
 	m_autoOpenTimer.stop();
-	KListView::contentsDragLeaveEvent(e);
+	TDEListView::contentsDragLeaveEvent(e);
 }
 
 /** Returns true if more than one netry is supported by this action type. Returns false for actions which support only one entry, e.g. about module etc. */
@@ -689,7 +689,7 @@ const bool CMainIndex::isMultiAction( const CItemBase::MenuAction type ) const {
 
 /** Is called when items should be moved. */
 void CMainIndex::moved( TQPtrList<TQListViewItem>& /*items*/, TQPtrList<TQListViewItem>& /*afterFirst*/, TQPtrList<TQListViewItem>& /*afterNow*/) {
-	qDebug("move items");
+	tqDebug("move items");
 }
 
 /** Opens an editor window to edit the modules content. */
@@ -741,7 +741,7 @@ void CMainIndex::saveBookmarks() {
 
 		if (i && (i->type() == CItemBase::BookmarkFolder)) { 
 			//found the bookmark folder
-			KStandardDirs stdDirs;
+			TDEStandardDirs stdDirs;
 
 			const TQString path = stdDirs.saveLocation("data", "bibletime/");
 			if (!path.isEmpty()) {
@@ -758,7 +758,7 @@ void CMainIndex::saveBookmarks() {
 }
 
 void CMainIndex::readSettings() {
- 	qDebug("CMainIndex::readSettings");
+ 	tqDebug("CMainIndex::readSettings");
 	
 	TQStringList openGroups = CBTConfig::get(CBTConfig::bookshelfOpenGroups);
 	for (TQStringList::Iterator it( openGroups.begin() ); it != openGroups.end(); ++it) {
@@ -863,7 +863,9 @@ void CMainIndex::saveSettings() {
 
 void CMainIndex::polish()
 {
-	KListView::polish();
+	TDEListView::polish();
 	initTree();
 	readSettings();
 }
+
+#include "cmainindex.moc"
