@@ -59,7 +59,7 @@ void myMessageOutput( TQtMsgType type, const char *msg ) {
 			fprintf( stderr,"(BibleTime %s) WARNING: %s\n",VERSION, msg );
 			break;
 		case TQtFatalMsg:
-			fprintf( stderr,"(BibleTime %s) _FATAL_: %s\nPlease visit http://bugs.pearsoncomputing.net and report this bug!",VERSION, msg );
+			fprintf( stderr,"(BibleTime %s) _FATAL_: %s\nPlease visit http://bugs.trinitydesktop.org and report this bug!",VERSION, msg );
 			abort(); // dump core on purpose
 	}
 }
@@ -137,7 +137,7 @@ int main(int argc, char* argv[]) {
 		I18N_NOOP("(c)1999-2010, The BibleTime Team and The Trinity Project"),
 		I18N_NOOP("BibleTime is an easy to use but powerful Bible study tool for Trinity.\nIt is a fork of the main BibleTime project in order to provide a native Trinity application.\n\nThe BibleTime project is looking for developers and translators.\nIf you'd like to join their team, please send an email to info@bibletime.info."),
 		"http://www.bibletime.info/",
-		"trinity-devel@lists.pearsoncomputing.net"
+		"devels@trinitydesktop.org"
 	);
 
 	/***********************************************
@@ -150,7 +150,7 @@ int main(int argc, char* argv[]) {
 	// artwork
 	aboutData.addAuthor("James Ots", I18N_NOOP("Crystal icons, crystal startlogo, webpage"), "me@jamesots.com", "http://www.jamesots.com");
 	// Trinity project maintainer
-	aboutData.addAuthor("Timothy Pearson", I18N_NOOP("Trinity project maintainer"), "kb9vqf@pearsoncomputing.net", "http://trinity.pearsoncomputing.net");
+	aboutData.addAuthor("Timothy Pearson", I18N_NOOP("Trinity project"), "kb9vqf@pearsoncomputing.net", "http://www.trinitydesktop.org");
 
 	//inactiv
 
